@@ -3,12 +3,11 @@ from __future__ import annotations
 import logging
 
 from datetime import datetime
-import sys
 from time import time
 from typing import Any, Dict, List
 
 from .const import VERSION, VERSION_APP
-from .exception_classes import FunctionError, LoginError, NoAdminError
+from .exception_classes import LoginError, NoAdminError
 from .gql_handler import GQLHandler
 from .pyxplora import PyXplora
 from .status import LocationType, NormalStatus, WatchOnlineStatus
@@ -82,7 +81,8 @@ class PyXploraApi(PyXplora):
         return "{0}-{1}".format(VERSION, VERSION_APP)
 
     def setDevices(self) -> PyXplora:
-        for wuid in self.getWatchUserIDs():
+        wuids: List[str] = self.getWatchUserIDs()
+        for wuid in wuids:
             self.device[wuid] = {}
             self.device[wuid]["getWatchAlarm"] = self.getWatchAlarm(wuid=wuid)
             self.device[wuid]["loadWatchLocation"] = self.loadWatchLocation(wuid=wuid)
@@ -104,7 +104,7 @@ class PyXploraApi(PyXplora):
             self.device[wuid]["getWatchOnlineStatus"] = self.getWatchOnlineStatus(wuid=wuid)
             self.device[wuid]["getWatchUserIcons"] = self.getWatchUserIcons(wuid=wuid)
             self.device[wuid]["getWatchUserXcoins"] = self.getWatchUserXcoins(wuid=wuid)
-        return self.device
+        return wuids
 
     ##### Contact Info #####
     def getWatchUserContacts(self, wuid: str) -> List[Dict[str, Any]]:
@@ -149,10 +149,7 @@ class PyXploraApi(PyXplora):
             if not dataOk:
                 self._logoff()
                 self.delay(self.retryDelay)
-        if dataOk:
-            return contacts
-        else:
-            raise FunctionError(sys._getframe().f_code.co_name)
+        return contacts
 
     def getWatchAlarm(self, wuid: str) -> List[Dict[str, Any]]:
         retryCounter = 0
@@ -184,10 +181,7 @@ class PyXploraApi(PyXplora):
             if not dataOk:
                 self._logoff()
                 self.delay(self.retryDelay)
-        if dataOk:
-            return alarms
-        else:
-            raise FunctionError(sys._getframe().f_code.co_name)
+        return alarms
 
     def loadWatchLocation(self, wuid: str = "", withAsk: bool = True) -> Dict[str, Any]:
         retryCounter = 0
@@ -246,10 +240,7 @@ class PyXploraApi(PyXplora):
             if not dataOk:
                 self._logoff()
                 self.delay(self.retryDelay)
-        if dataOk:
-            return watch_location
-        else:
-            raise FunctionError(sys._getframe().f_code.co_name)
+        return watch_location
 
     def getWatchBattery(self, wuid: str) -> int:
         watch_b: List[Dict[str, Any]] = self.loadWatchLocation(wuid=wuid)
@@ -283,10 +274,7 @@ class PyXploraApi(PyXplora):
             if dataOk is WatchOnlineStatus.UNKNOWN:
                 self._logoff()
                 self.delay(self.retryDelay)
-        if dataOk:
-            return asktrack_raw.value
-        else:
-            raise FunctionError(sys._getframe().f_code.co_name)
+        return asktrack_raw.value
 
     """def __setReadChatMsg(self, msgId, id):
         return (self._gqlHandler.setReadChatMsg(self.getWatchUserIDs(), msgId, id))["setReadChatMsg"]"""
@@ -336,10 +324,7 @@ class PyXploraApi(PyXplora):
             if not dataOk:
                 self._logoff()
                 self.delay(self.retryDelay)
-        if dataOk:
-            return chats
-        else:
-            raise FunctionError(sys._getframe().f_code.co_name)
+        return chats
 
     ##### Watch Location Info #####
     def getWatchLastLocation(self, wuid: str, withAsk: bool = False) -> Dict[str, Any]:
@@ -398,10 +383,7 @@ class PyXploraApi(PyXplora):
             if not dataOk:
                 self._logoff()
                 self.delay(self.retryDelay)
-        if dataOk:
-            return safe_zones
-        else:
-            raise FunctionError(sys._getframe().f_code.co_name)
+        return safe_zones
 
     def getTrackWatchInterval(self, wuid: str) -> int:
         return self._gqlHandler.trackWatch(wuid).get("trackWatch", -1)
@@ -440,10 +422,7 @@ class PyXploraApi(PyXplora):
             if not dataOk:
                 self._logoff()
                 self.delay(self.retryDelay)
-        if dataOk:
-            return school_silent_mode
-        else:
-            raise FunctionError(sys._getframe().f_code.co_name)
+        return school_silent_mode
 
     def setEnableSilentTime(self, silentId: str, wuid: str) -> bool:
         retryCounter = 0
@@ -464,10 +443,7 @@ class PyXploraApi(PyXplora):
             if not dataOk:
                 self._logoff()
                 self.delay(self.retryDelay)
-        if dataOk:
-            return bool(_raw)
-        else:
-            raise FunctionError(sys._getframe().f_code.co_name)
+        return bool(_raw)
 
     def setDisableSilentTime(self, silentId: str, wuid: str) -> bool:
         retryCounter = 0
@@ -488,10 +464,7 @@ class PyXploraApi(PyXplora):
             if not dataOk:
                 self._logoff()
                 self.delay(self.retryDelay)
-        if dataOk:
-            return bool(_raw)
-        else:
-            raise FunctionError(sys._getframe().f_code.co_name)
+        return bool(_raw)
 
     def setAllEnableSilentTime(self, wuid: str) -> List[bool]:
         res: List[bool] = []
@@ -524,10 +497,7 @@ class PyXploraApi(PyXplora):
             if not dataOk:
                 self._logoff()
                 self.delay(self.retryDelay)
-        if dataOk:
-            return bool(_raw)
-        else:
-            raise FunctionError(sys._getframe().f_code.co_name)
+        return bool(_raw)
 
     def setDisableAlarmTime(self, alarmId: str, wuid: str) -> bool:
         retryCounter = 0
@@ -548,10 +518,7 @@ class PyXploraApi(PyXplora):
             if not dataOk:
                 self._logoff()
                 self.delay(self.retryDelay)
-        if dataOk:
-            return bool(_raw)
-        else:
-            raise FunctionError(sys._getframe().f_code.co_name)
+        return bool(_raw)
 
     def setAllEnableAlarmTime(self, wuid: str) -> List[bool]:
         res: List[bool] = []
@@ -618,10 +585,7 @@ class PyXploraApi(PyXplora):
             if not dataOk:
                 self._logoff()
                 self.delay(self.retryDelay)
-        if dataOk:
-            return watches
-        else:
-            raise FunctionError(sys._getframe().f_code.co_name)
+        return watches
 
     def getSWInfo(self, wuid: str, watches: Dict[str, Any] = {}) -> Dict[str, Any]:
         wqr: Dict[str, Any] = watches if watches is not None else self.getWatches(wuid=wuid)
