@@ -4,12 +4,12 @@ import logging
 
 from asyncio import sleep
 from datetime import datetime
-import sys
+import asyncio
 from time import time
 from typing import Any, Dict, List
 
 from .const import VERSION, VERSION_APP
-from .exception_classes import FunctionError, LoginError, NoAdminError
+from .exception_classes import LoginError, NoAdminError
 from .gql_handler_async import GQLHandler
 from .pyxplora import PyXplora
 from .status import LocationType, NormalStatus, WatchOnlineStatus
@@ -83,10 +83,14 @@ class PyXploraApi(PyXplora):
         return "{0}-{1}".format(VERSION, VERSION_APP)
 
     async def setDevices(self) -> List[Dict[str, Any]]:
-        for wuid in self.getWatchUserIDs():
+        return await self._setDevices()
+
+    async def _setDevices(self) -> List[Dict[str, Any]]:
+        wuids: List[str] = self.getWatchUserIDs()
+        for wuid in wuids:
             self.device[wuid] = {}
-            self.device[wuid]["getWatchAlarm"] = await self.getWatchAlarm(wuid=wuid)
-            self.device[wuid]["loadWatchLocation"] = await self.loadWatchLocation(wuid=wuid)
+            self.device[wuid]["getWatchAlarm"] = asyncio.create_task(self.getWatchAlarm(wuid=wuid))
+            self.device[wuid]["loadWatchLocation"] = await asyncio.create_task(self.loadWatchLocation(wuid=wuid))
             self.device[wuid]["watch_battery"] = int(self.device[wuid]["loadWatchLocation"].get("watch_battery", -1))
             self.device[wuid]["watch_charging"] = self.device[wuid]["loadWatchLocation"].get("watch_charging", False)
             self.device[wuid]["locateType"] = self.device[wuid]["loadWatchLocation"].get(
@@ -94,18 +98,24 @@ class PyXploraApi(PyXplora):
             )
             self.device[wuid]["isInSafeZone"] = self.device[wuid]["loadWatchLocation"].get("isInSafeZone", False)
             self.device[wuid]["safeZoneLabel"] = self.device[wuid]["loadWatchLocation"].get("safeZoneLabel", "")
-            self.device[wuid]["getWatchSafeZones"] = await self.getWatchSafeZones(wuid=wuid)
-            self.device[wuid]["getSilentTime"] = await self.getSilentTime(wuid=wuid)
-            self.device[wuid]["getWatches"] = await self.getWatches(wuid=wuid)
-            self.device[wuid]["getSWInfo"] = await self.getSWInfo(wuid=wuid, watches=self.device[wuid]["getWatches"])
-            self.device[wuid]["getWatchState"] = await self.getWatchState(wuid=wuid, watches=self.device[wuid]["getWatches"])
+            self.device[wuid]["getWatchSafeZones"] = asyncio.create_task(self.getWatchSafeZones(wuid=wuid))
+            self.device[wuid]["getSilentTime"] = asyncio.create_task(self.getSilentTime(wuid=wuid))
+            self.device[wuid]["getWatches"] = await asyncio.create_task(self.getWatches(wuid=wuid))
+            self.device[wuid]["getSWInfo"] = asyncio.create_task(
+                self.getSWInfo(wuid=wuid, watches=self.device[wuid]["getWatches"])
+            )
+            self.device[wuid]["getWatchState"] = asyncio.create_task(
+                self.getWatchState(wuid=wuid, watches=self.device[wuid]["getWatches"])
+            )
             d = datetime.now()
             dt = datetime(year=d.year, month=d.month, day=d.day)
-            self.device[wuid]["getWatchUserSteps"] = await self.getWatchUserSteps(wuid=wuid, date=dt.timestamp())
-            self.device[wuid]["getWatchOnlineStatus"] = await self.getWatchOnlineStatus(wuid=wuid)
+            self.device[wuid]["getWatchUserSteps"] = asyncio.create_task(
+                self.getWatchUserSteps(wuid=wuid, date=dt.timestamp())
+            )
+            self.device[wuid]["getWatchOnlineStatus"] = asyncio.create_task(self.getWatchOnlineStatus(wuid=wuid))
             self.device[wuid]["getWatchUserIcons"] = self.getWatchUserIcons(wuid=wuid)
             self.device[wuid]["getWatchUserXcoins"] = self.getWatchUserXcoins(wuid=wuid)
-        return self.device
+        return wuids
 
     ##### Contact Info #####
     async def getWatchUserContacts(self, wuid: str) -> List[Dict[str, Any]]:
@@ -150,10 +160,7 @@ class PyXploraApi(PyXplora):
             if not dataOk:
                 self._logoff()
                 await sleep(self.retryDelay)
-        if dataOk:
-            return contacts
-        else:
-            raise FunctionError(sys._getframe().f_code.co_name)
+        return contacts
 
     async def getWatchAlarm(self, wuid: str) -> List[Dict[str, Any]]:
         retryCounter = 0
@@ -185,10 +192,7 @@ class PyXploraApi(PyXplora):
             if not dataOk:
                 self._logoff()
                 await sleep(self.retryDelay)
-        if dataOk:
-            return alarms
-        else:
-            raise FunctionError(sys._getframe().f_code.co_name)
+        return alarms
 
     async def loadWatchLocation(self, wuid: str = "", withAsk: bool = True) -> Dict[str, Any]:
         retryCounter = 0
@@ -247,10 +251,7 @@ class PyXploraApi(PyXplora):
             if not dataOk:
                 self._logoff()
                 await sleep(self.retryDelay)
-        if dataOk:
-            return watch_location
-        else:
-            raise FunctionError(sys._getframe().f_code.co_name)
+        return watch_location
 
     async def getWatchBattery(self, wuid: str) -> int:
         watch_b: List[Dict[str, Any]] = await self.loadWatchLocation(wuid=wuid)
@@ -284,10 +285,7 @@ class PyXploraApi(PyXplora):
             if dataOk is WatchOnlineStatus.UNKNOWN:
                 self._logoff()
                 await sleep(self.retryDelay)
-        if dataOk:
-            return asktrack_raw.value
-        else:
-            raise FunctionError(sys._getframe().f_code.co_name)
+        return asktrack_raw.value
 
     """async def __setReadChatMsg_a(self, msgId, id):
         return (await self._gqlHandler.setReadChatMsg(self.getWatchUserIDs(), msgId, id))["setReadChatMsg"]"""
@@ -337,10 +335,7 @@ class PyXploraApi(PyXplora):
             if not dataOk:
                 self._logoff()
                 await sleep(self.retryDelay)
-        if dataOk:
-            return chats
-        else:
-            raise FunctionError(sys._getframe().f_code.co_name)
+        return chats
 
     ##### Watch Location Info #####
     async def getWatchLastLocation(self, wuid: str, withAsk: bool = False) -> Dict[str, Any]:
@@ -399,10 +394,7 @@ class PyXploraApi(PyXplora):
             if not dataOk:
                 self._logoff()
                 await sleep(self.retryDelay)
-        if dataOk:
-            return safe_zones
-        else:
-            raise FunctionError(sys._getframe().f_code.co_name)
+        return safe_zones
 
     async def getTrackWatchInterval(self, wuid: str) -> int:
         return (await self._gqlHandler.trackWatch_a(wuid)).get("trackWatch", -1)
@@ -441,10 +433,7 @@ class PyXploraApi(PyXplora):
             if not dataOk:
                 self._logoff()
                 await sleep(self.retryDelay)
-        if dataOk:
-            return school_silent_mode
-        else:
-            raise FunctionError(sys._getframe().f_code.co_name)
+        return school_silent_mode
 
     async def setEnableSilentTime(self, silentId: str, wuid: str) -> bool:
         retryCounter = 0
@@ -465,10 +454,7 @@ class PyXploraApi(PyXplora):
             if not dataOk:
                 self._logoff()
                 await sleep(self.retryDelay)
-        if dataOk:
-            return bool(_raw)
-        else:
-            raise FunctionError(sys._getframe().f_code.co_name)
+        return bool(_raw)
 
     async def setDisableSilentTime(self, silentId: str, wuid: str) -> bool:
         retryCounter = 0
@@ -489,10 +475,7 @@ class PyXploraApi(PyXplora):
             if not dataOk:
                 self._logoff()
                 await sleep(self.retryDelay)
-        if dataOk:
-            return bool(_raw)
-        else:
-            raise FunctionError(sys._getframe().f_code.co_name)
+        return bool(_raw)
 
     async def setAllEnableSilentTime(self, wuid: str) -> List[bool]:
         res: List[bool] = []
@@ -525,10 +508,7 @@ class PyXploraApi(PyXplora):
             if not dataOk:
                 self._logoff()
                 await sleep(self.retryDelay)
-        if dataOk:
-            return bool(_raw)
-        else:
-            raise FunctionError(sys._getframe().f_code.co_name)
+        return bool(_raw)
 
     async def setDisableAlarmTime(self, alarmId: str, wuid: str) -> bool:
         retryCounter = 0
@@ -549,10 +529,7 @@ class PyXploraApi(PyXplora):
             if not dataOk:
                 self._logoff()
                 await sleep(self.retryDelay)
-        if dataOk:
-            return bool(_raw)
-        else:
-            raise FunctionError(sys._getframe().f_code.co_name)
+        return bool(_raw)
 
     async def setAllEnableAlarmTime(self, wuid: str) -> List[bool]:
         res: List[bool] = []
@@ -619,10 +596,7 @@ class PyXploraApi(PyXplora):
             if not dataOk:
                 self._logoff()
                 await sleep(self.retryDelay)
-        if dataOk:
-            return watches
-        else:
-            raise FunctionError(sys._getframe().f_code.co_name)
+        return watches
 
     async def getSWInfo(self, wuid: str, watches: Dict[str, Any] = {}) -> Dict[str, Any]:
         wqr: Dict[str, Any] = watches if watches else await self.getWatches(wuid=wuid)
